Trait html_query_parser::Queryable[][src]

pub trait Queryable {
    fn query(&self, selector: &Selector) -> Option<Element>;
fn query_all(&self, selector: &Selector) -> Vec<Element>; }
Implement query(), query_all() methods to Vec<Node> and Element.

Required methods

Query the node in self for the given selector.

Query all the nodes in self for the given selector.

Implementations on Foreign Types

Implementors